<?php

namespace Drupal\tooltip_example\Form;

use Drupal\Core\Ajax\AjaxFormHelperTrait;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\AlertCommand;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides an example Ajax form.
 */
class TooltipExampleAjaxForm extends FormBase {

  use AjaxFormHelperTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tooltip_example_ajax_form';
  }

  /**
   * Builds the form.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['email'] = [
      '#type' => 'email',
      '#title' => $this->t('Subscribe to our newsletter'),
      '#required' => TRUE,
      '#attributes' => ['size' => 30],
    ];

    $form['actions'] = ['#type' => 'container'];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Subscribe'),
      '#button_type' => 'primary',
      '#op' => 'subscribe',
      '#ajax' => [
        'callback' => '::ajaxSubmit',
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Subscribe the user, for instance:
    // \Drupal::httpClient()->post($newsletter_api_url, [
    //  'body' => Json::encode(['email' => $form_state->getValue('email')]),
    //  ...etc.
    // ]);
  }

  /**
   * {@inheritdoc}
   */
  protected function successfulAjaxSubmit(array $form, FormStateInterface $form_state) {
    $message = $this->t('You are now subscribed to our newsletter!');

    $response = new AjaxResponse();
    $response->addCommand(new AlertCommand($message));
    return $response;
  }

}
