<?php

namespace Drupal\tooltip\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\RendererInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Returns responses for tooltip module routes.
 */
class TooltipController extends ControllerBase {

  /**
   * The renderer.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructs our object.
   */
  public function __construct(RendererInterface $renderer) {
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('renderer')
    );
  }

  /**
   * Presents the aggregator feed creation form.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   A JSON response containing the block content in "html".
   */
  public function getBlock(string $uuid) {
    // Lookup for a block.
    $blocks = $this->entityTypeManager()->getStorage('block')
      ->loadByProperties(['uuid' => $uuid]);

    // Lookup for a content block.
    if (empty($blocks)) {
      if ($this->entityTypeManager()->hasHandler('block_content', 'storage')) {
        $blocks = $this->entityTypeManager()->getStorage('block_content')
          ->loadByProperties(['uuid' => $uuid]);
      }
    }

    $content = NULL;

    if ($block = reset($blocks) ?? NULL) {
      $build = $this->entityTypeManager()
        ->getViewBuilder($block->getEntityTypeId())
        ->view($block, '');

      $content = $this->renderer->render($build);
    }

    $response = new JsonResponse([
      'content' => $content,
    ], 201);

    // Required to verify Ajax call.
    $response->headers->set('X-Drupal-Ajax-Token', 1);

    return $response;
  }

}
