<?php

namespace Drupal\tooltip\Plugin\Block;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\node\NodeInterface;
use Drupal\tooltip\TooltipBlockBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A block to display a node in a Tooltip.
 *
 * @Block(
 *   id = "tooltip_node_block",
 *   admin_label = @Translation("Tooltip from Node"),
 *   category = @Translation("Tooltip")
 * )
 */
class TooltipNodeBlock extends TooltipBlockBase implements ContainerFactoryPluginInterface {

  /**
   * The node storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * The node view builder.
   *
   * @var \Drupal\node\NodeViewBuilder
   */
  protected $nodeViewBuilder;

  /**
   * {@inheritDoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->nodeStorage = $entity_type_manager->getStorage('node');
    $this->nodeViewBuilder = $entity_type_manager->getViewBuilder('node');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'node' => null,
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $nid = $this->configuration['node'] ?? NULL;
    $node = $nid ? $this->nodeStorage->load($nid) : NULL;

    $form['node'] = [
      '#title' => $this->t('Node'),
      '#type' => 'entity_autocomplete',
      '#target_type' => 'node',
      '#default_value' => $node,
      '#selection_handler' => 'default',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['node'] = $form_state->getValue('node');
  }

  /**
   * {@inheritdoc}
   */
  public function tooltip(array &$build) {
    $nid = $this->configuration['node'] ?? NULL;
    $node = $nid ? $this->nodeStorage->load($nid) : NULL;
    $build['node'] = $node ? $this->nodeViewBuilder->view($node, 'tooltip') : [];
    $build['#access'] = $node instanceof NodeInterface;
  }

}
