<?php

namespace Drupal\tooltip;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Security\TrustedCallbackInterface;
use Drupal\tooltip\TooltipBlockPluginInterface;

/**
 * Defines a base block implementation that most Tooltip blocks will extend.
 *
 * @ingroup block_api
 */
abstract class TooltipBlockBase extends BlockBase implements TrustedCallbackInterface, TooltipBlockPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function build() {
    // Set custom attributes.
    // Important note: [data-uuid] cannot be set here.
    // @see tooltip_block_view_alter();
    $build['#attributes']['class'][] = 'tooltip';
    $build['#attributes']['class'][] = 'visually-hidden';

    // Append arrow.
    $build['#pre_render'][] = '\Drupal\tooltip\TooltipBlockBase::appendArrow';

    // Populate block content.
    $this->tooltip($build);

    // Attach required JS library.
    $build['#attached']['library'][] = 'tooltip/tooltip';

    return $build;
  }

  /**
   * #pre_render callback for a tooltip block.
   *
   * The `[data-popper-arrow]` will be misplaced inside `.block__content`.
   * There is no way to place this element outside of the wrapper.
   * It is consequently move at this block's div root via JavaScript.
   *
   * @see \Drupal\block\BlockViewBuilder::preRender();
   * @see js/tooltip.js
   */
  public static function appendArrow(array $build) {
    // Popper arrow.
    // @see https://popper.js.org/docs/v2/tutorial/#arrow
    // @see https://popper.js.org/docs/v2/modifiers/arrow/
    $build['arrow'] = ['#markup' => '<div data-popper-arrow class="tooltip-arrow"></div>'];

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    return ['appendArrow'];
  }

}
